# Generated by Django 4.2 on 2024-03-06 22:11

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("userextensions", "0007_auto_20220807_2104"),
    ]

    operations = [
        migrations.AlterField(
            model_name="serviceaccount",
            name="id",
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID"),
        ),
        migrations.AlterField(
            model_name="serviceaccounttokenhistory",
            name="id",
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID"),
        ),
        migrations.AlterField(
            model_name="theme",
            name="id",
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID"),
        ),
        migrations.AlterField(
            model_name="userfavorite",
            name="id",
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID"),
        ),
        migrations.AlterField(
            model_name="userpreference",
            name="id",
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID"),
        ),
        migrations.AlterField(
            model_name="userpreference",
            name="timezone",
            field=models.CharField(
                blank=True,
                default="UTC",
                help_text="timezone to use when displaying time and datetime values",
                max_length=32,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="userrecent",
            name="id",
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID"),
        ),
    ]
