# Generated by Django 3.2.13 on 2022-08-07 21:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('userextensions', '0006_auto_20210507_1831'),
    ]

    operations = [
        migrations.AddField(
            model_name='userpreference',
            name='help_text_enable',
            field=models.BooleanField(default=True, help_text='enable help text and tooltips'),
        ),
        migrations.AddField(
            model_name='userpreference',
            name='timezone',
            field=models.CharField(blank=True, help_text='timezone to use when displaying time and datetime values', max_length=32, null=True),
        ),
        migrations.AlterField(
            model_name='serviceaccount',
            name='id',
            field=models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='serviceaccounttokenhistory',
            name='id',
            field=models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='id',
            field=models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='userfavorite',
            name='id',
            field=models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='userpreference',
            name='id',
            field=models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='userrecent',
            name='id',
            field=models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
    ]
